@@ -952,7 +952,24 @@ void server::reload(void)
     // separate user editable local provisioning in /etc/sipwitch.d from
     // such global data as part of a complete solution.
 
+    node = cfgp->getPath("access");
+    if(node)
+        fp = fopen(_STR(control::path("cache") + "/policy.xml"), "r");
+    if(node && fp) {
+        if(!cfgp->load(fp, node))
+             shell::log(shell::ERR, "cannot load policy cache");
+    }
+
     node = cfgp->getPath("provision");
+
+    // can load profiles separate from user provisioning...
+    if(node)
+        fp = fopen(_STR(control::path("cache") + "/profile.xml"), "r");
+    if(node && fp) {
+        if(!cfgp->load(fp, node))
+             shell::log(shell::ERR, "cannot load profile cache");
+    }
+
     if(node)
         fp = fopen(_STR(control::path("cache") + "/provision.xml"), "r");
     if(node && fp) {
@@ -960,6 +977,33 @@ void server::reload(void)
             shell::log(shell::ERR, "cannot load provisioning cache");
     }
 
+    // scan for user records individually also...
+    const char *dirpath = _STR(control::path("cache"));
+    char filename[65];
+    dir_t dir(dirpath);
+    while(node && is(dir) && dir.read(filename, sizeof(filename)) > 0) {
+        const char *ext = strrchr(filename, '.');
+        if(!ext || !String::equal(ext, ".xml"))
+            continue;
+        if(!String::equal(filename, "user-", 5))
+            continue; 
+        snprintf(buf, sizeof(buf), "%s/%s", dirpath, filename);
+        fp = fopen(buf, "r");
+        if(!fp)
+            continue;
+        if(!cfgp->load(fp, node))
+            shell::log(shell::ERR, "cannot load user cache %s", filename);
+    }
+    dir.close();
+
+    node = cfgp->getPath("provider");
+    if(node)
+        fp = fopen(_STR(control::path("cache") + "/provider.xml"), "r");
+    if(node && fp) {
+        if(!cfgp->load(fp, node))
+             shell::log(shell::ERR, "cannot load provider cache");
+    }
+
     node = cfgp->getPath("routing");
     if(node)
         fp = fopen(_STR(control::path("cache") + "/routing.xml"), "r");
@@ -997,7 +1041,7 @@ caddr_t server::allocate(size_t size, LinkedObject **list, volatile unsigned *co
     return mp;
 }
 
-#ifdef  _MSWINDOWS_
+#ifdef _MSWINDOWS_
 #define LIB_PREFIX  "_libs"
 #else
 #define LIB_PREFIX  ".libs"
